| Home | Libraries | People | FAQ | More

### is_compound

    template <class T>
    struct is_compound : public true_type-or-false_type {};

Inherits: If T is a (possibly cv-qualified) compound type then inherits from true_type, otherwise inherits from false_type. Any type that is not a fundamental type is a compound type (see also is_fundamental).

C++ Standard Reference: 3.9.2.

Header: `#include <boost/type_traits/is_compound.hpp>` or `#include <boost/type_traits.hpp>`

Examples:

> `is_compound<MyClass>` inherits from `true_type`.

> `is_compound<MyEnum>::type` is the type `true_type`.

> `is_compound<int*>::value` is an integral constant expression that evaluates to true.

> `is_compound<int&>::value` is an integral constant expression that evaluates to true.

> `is_compound<int>::value` is an integral constant expression that evaluates to false.

> `is_compound<T>::value_type` is the type `bool`.